@@ -3,7 +3,7 @@ from dotenv import load_dotenv
 load_dotenv()
 
 from . import config
-from .abraia import Abraia, APIError
+from .client import Abraia, APIError
 from .multiple import Multiple
 
 __all__ = ['config', 'Abraia', 'APIError', 'Multiple']
