@@ -26,34 +26,29 @@ def base64decode(str):
     return str.decode('ascii') if isinstance(str, bytes) else str
 
 
-def load_auth():
+def load():
+    abraia_id = os.environ.get('ABRAIA_ID')
     abraia_key = os.environ.get('ABRAIA_KEY')
-    if abraia_key:
-        api_key, api_secret = base64decode(abraia_key).split(':')
-        return api_key, api_secret
+    if abraia_id and abraia_key:
+        return abraia_id, abraia_key
     elif os.path.isfile(CONFIG_FILE):
         config = {}
         with open(CONFIG_FILE, 'r') as f:
             for line in f:
                 key, value = list(map(lambda v: v.strip(), line.split(':')))
                 config[key] = value
-        return config['abraia_api_key'], config['abraia_api_secret']
+        return config.get('abraia_id', ''), config.get('abraia_key', '')
     return '', ''
 
 
-def save_auth(api_key, api_secret):
-    content = ('abraia_api_key: {}\n'
-               'abraia_api_secret: {}\n').format(api_key, api_secret)
+def load_auth(abraia_key):
+    if abraia_key:
+        api_key, api_secret = base64decode(abraia_key).split(':')
+        return api_key, api_secret
+    return '', ''
+
+
+def save(abraia_id, abraia_key):
+    content = ('abraia_id: {}\nabraia_key: {}\n').format(abraia_id, abraia_key)
     with open(CONFIG_FILE, 'w') as f:
         f.write(content)
-
-
-def load_key():
-    api_key, api_secret = load_auth()
-    abraia_key = base64encode('{}:{}'.format(api_key, api_secret)) if api_key and api_secret else ''
-    return abraia_key
-
-
-def save_key(abraia_key):
-    api_key, api_secret = base64decode(abraia_key).split(':')
-    save_auth(api_key, api_secret)
